@@ -1,6 +1,7 @@
 from pyliveupdate.update import Instrument, UpdateManager
 from pyliveupdate.stub import remote_logger, local_logger
 from pyliveupdatescripts.updatebase import UpdateBase
+from collections.abc import Iterable
 import time
 
 class LineProfiler(UpdateBase):
@@ -16,14 +17,19 @@ class LineProfiler(UpdateBase):
         remote_logger.info('{:.4f} ms'.format(time_))
     
     @staticmethod
-    def profile(scope):
+    def profile(scope, lines):
         scopes = scope
         if isinstance(scope, str):
-            scopes = [scope]
+            scopes = [scope] 
+        if not isinstance(lines, Iterable):
+            lines = (lines,)
+        else:
+            lines = tuple(lines)
+            
         for scope in scopes:
             update = Instrument(scope, 
-                            {'line_before': LineProfiler._line_before, 
-                             'line_after': LineProfiler._line_after})
+                            {('line_before', lines): LineProfiler._line_before, 
+                             ('line_after', lines): LineProfiler._line_after})
             UpdateManager.apply_update(update)
 
 LP = LineProfiler
